function [trw,gT,gM,gE,M] = test_vslite_v2_2(site)
% Usage: [trw,gT,gM,gE,M] = test_vslite(site)
% Input: 'site' is either 1, 2, 3, or 4, runs VS-Lite at one of four test sites.
%   Site 1: 36.45N, -118.22E, 'ca530'
%   Site 2: 34.17N, -117.12E, 'ca544'
%   Site 3: 39.02N, -122.82E, 'ca615'
%   Site 4: 39.32N, -106.08E, 'co523'
% Outputs: same outputs as for VSLite model.
% Monthly input climate data is from the OSU PRISM data product for the years 1895 through 1984. 
% Observed chronologies are from the International Tree Ring Data Bank, but have been standardized
% for the period 1895-1984.
% Parameters used are the modes of those found to be 'optimal' over 100 calibration/verification
% tests in Tolwinski-Ward et al., 2010
% SETW 11/2010
% SETW: Updated 11/2011 to run with updated VSLite version 2.2 

% If user doesn't specify site, just run the first one.
if nargin == 0; site = 1; end
% load the test data:
load vslite_testdata.mat
% select climate data for the chosen test site:
T = m08clim(site).T;
P = m08clim(site).P;
% select the climate response parameters:
T1 = optimal_pars(site).T1;
T2 = optimal_pars(site).T2;
M1 = optimal_pars(site).M1;
M2 = optimal_pars(site).M2;
% select latitude of the site:
phi = sitecoords(site,1);
% load the default parameters of the CPC Leaky Bucket Model:
Mmax = 0.76;
Mmin = 0.01;
alph = 0.093;
m_th = 4.886;
mu_th = 5.8;
rootd = 1000;
% Parameters controlling the start and end months of the integration window:
I_0 = -4; % (default)
I_f = 12; % (default)
% Parameters controlling initial soil moisture and whether or not to use the Leaky Bucket model's
% substepping option:
M0 = .2; % (default) 
substep = 0; % (default)
% Run VS-Lite.
[trw,gT,gM,gE,M,potEv] = VSLite_v2_2(syear,eyear,phi,T1,T2,M1,M2,T,P,...
    Mmax,Mmin,alph,m_th,mu_th,rootd,M0,substep,I_0,I_f);
% Draw some output.
figure;
set(gcf,'units','normalized','position',[.25 .25 .5 .4])

if exist('worldmap')
    subplot(2,2,2);
    plot(mean(gM,2),'b--'); xlim([1 12]); hold on;
    plot(mean(gT,2),'r');
    title('Mean gT (red) and gM (blue)')
    subplot(2,2,1)
    worldmap([27 50],[-127 -65])
    load coast
    plotm(lat,long,'k')
    hold on; plotm(sitecoords(site,1),sitecoords(site,2),'*r','markersize',8)
    title('Site location')
    subplot(2,1,2);
    plot(syear:eyear,trw,'rx-'); hold on
    plot(syear:eyear,trw_obs(:,site),'kd-'); xlim([syear eyear]);
    eval(['title(''Simulated RW (red) and observed (black)'')']);
    ylim([min(min(trw),min(trw_obs(:,site))) max(max(trw),max(trw_obs(:,site)))]);
elseif exist('m_proj')
    subplot(2,2,2);
    plot(mean(gM,2),'b--'); xlim([1 12]); hold on;
    plot(mean(gT,2),'r');
    title('Mean gT (red) and gM (blue)')
    subplot(2,2,1)
    m_proj('Equidistant Cylindrical','longitude',[-127 -65],'latitude',[27 50])
    m_coast('color','k')
    m_grid
    m_line(sitecoords(site,2),sitecoords(site,1),'marker','*','color','r','markersize',8)
    title('Site location')
    subplot(2,1,2);
    plot(syear:eyear,trw,'rx-'); hold on
    plot(syear:eyear,trw_obs(:,site),'kd-'); xlim([syear eyear]);
    eval(['title(''Simulated RW (red) and observed (black)'')']);
    ylim([min(min(trw),min(trw_obs(:,site))) max(max(trw),max(trw_obs(:,site)))]);
else
    subplot(2,1,1);
    plot(mean(gM,2),'b--'); xlim([1 12]); hold on;
    plot(mean(gT,2),'r');
    title('Mean gT (red) and gM (blue)')
    subplot(2,1,2);
    plot(syear:eyear,trw,'rx-'); hold on
    plot(syear:eyear,trw_obs(:,site),'kd-'); xlim([syear eyear]);
    eval(['title(''Simulated RW (red) and observed (black)'')']);
end
    
